==> glue-1.93.0-sources.jar: software/amazon/awscdk/services/glue/ClassificationString.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) Classification string given to tables with this data format.
 * <p>
 * @see https://docs.aws.amazon.com/glue/latest/dg/add-classifier.html#classifier-built-in
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.482Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.ClassificationString")
public class ClassificationString extends software.amazon.jsii.JsiiObject {

    protected ClassificationString(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ClassificationString(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AVRO = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "AVRO", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
        CSV = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "CSV", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
        JSON = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "JSON", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
        ORC = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "ORC", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
        PARQUET = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "PARQUET", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
        XML = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "XML", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public ClassificationString(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @see https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-avro
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString AVRO;

    /**
     * @see https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-csv
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString CSV;

    /**
     * @see https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-json
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString JSON;

    /**
     * @see https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-orc
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString ORC;

    /**
     * @see https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-parquet
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString PARQUET;

    /**
     * @see https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-xml
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString XML;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getValue() {
        return software.amazon.jsii.Kernel.get(this, "value", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> glue-1.182.0-sources.jar: software/amazon/awscdk/services/glue/ClassificationString.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) Classification string given to tables with this data format.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.glue.*;
 * ClassificationString classificationString = ClassificationString.AVRO;
 * </pre></blockquote>
 * <p>
 * @see <a href="https://docs.aws.amazon.com/glue/latest/dg/add-classifier.html#classifier-built-in">https://docs.aws.amazon.com/glue/latest/dg/add-classifier.html#classifier-built-in</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:43.436Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.ClassificationString")
public class ClassificationString extends software.amazon.jsii.JsiiObject {

    protected ClassificationString(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ClassificationString(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AVRO = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "AVRO", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
        CSV = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "CSV", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
        JSON = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "JSON", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
        ORC = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "ORC", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
        PARQUET = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "PARQUET", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
        XML = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.ClassificationString.class, "XML", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.ClassificationString.class));
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public ClassificationString(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @see <a href="https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-avro">https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-avro</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString AVRO;

    /**
     * @see <a href="https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-csv">https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-csv</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString CSV;

    /**
     * @see <a href="https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-json">https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-json</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString JSON;

    /**
     * @see <a href="https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-orc">https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-orc</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString ORC;

    /**
     * @see <a href="https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-parquet">https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-parquet</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString PARQUET;

    /**
     * @see <a href="https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-xml">https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html#aws-glue-programming-etl-format-xml</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.ClassificationString XML;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getValue() {
        return software.amazon.jsii.Kernel.get(this, "value", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
